@@ -159,10 +159,7 @@ sub true {
     my $class = shift;
     my $argvs = shift // return undef;
 
-    return undef unless ref $argvs eq 'Sisimai::Data';
     return 1 if $argvs->reason eq 'blocked';
-
-    require Sisimai::SMTP::Status;
     return 1 if Sisimai::SMTP::Status->name($argvs->deliverystatus) eq 'blocked';
     return 1 if __PACKAGE__->match(lc $argvs->diagnosticcode);
 }
