@@ -41,11 +41,8 @@ sub true {
     # @see http://www.ietf.org/rfc/rfc2822.txt
     my $class = shift;
     my $argvs = shift // return undef;
-
-    return undef unless ref $argvs eq 'Sisimai::Data';
     return 1 if $argvs->reason eq 'mesgtoobig';
 
-    require Sisimai::SMTP::Status;
     my $statuscode = $argvs->deliverystatus // '';
     my $tempreason = Sisimai::SMTP::Status->name($statuscode);
 
